primecountpy: Cython interface for C++ primecount library
=========================================================

Description
-----------

primecountpy is a Cython interface for the C++ primecount library.

We are using the compatible fork passagemath-primesieve-primecount.

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/passagemath-primesieve-primecount/

